@@ -38,6 +38,22 @@ class DomainAdaptationDataModule(LightningDataBase):
         self.available_domains = []
         self.pre_split = False
 
+    def get_train_transform(self):
+        if self.train_transform:
+            print("Using user-defined training data augmentation")
+            return self.train_transform
+        else:
+            print("Using default training data augmentation")
+            return self._default_train_transforms
+
+    def get_test_transform(self):
+        if self.test_transform:
+            print("Using user-defined test data augmentation")
+            return self.test_transform
+        else:
+            print("Using default test data augmentation")
+            return self._default_test_transforms
+
     def __prepare_dataset(self, root: str, remote_folder: str, ds_name: str, domain: str, split: bool) -> bool:
         print("Domain " + domain + " available")
         dataset_path = os.path.join(root, ds_name)
@@ -99,7 +115,7 @@ class DomainAdaptationDataModule(LightningDataBase):
         if self.pre_split:
             # pre-splitted dataset handling
             dataset_full = ImageFolderLMDB(db_path=self.data_dir_domain + "_train",
-                                           transform=self._default_train_transforms())
+                                           transform=self.get_train_transform())
 
             # set the number of classes and class names once
             self.num_classes = dataset_full.num_classes()
@@ -112,7 +128,7 @@ class DomainAdaptationDataModule(LightningDataBase):
         else:
             # non pre-splitted dataset handling
             dataset_full = ImageFolderLMDB(db_path=self.data_dir_domain,
-                                           transform=self._default_train_transforms())
+                                           transform=self.get_train_transform())
 
             # set the number of classes and class names once
             self.num_classes = dataset_full.num_classes()
@@ -126,7 +142,7 @@ class DomainAdaptationDataModule(LightningDataBase):
 
         if self.pre_split:
             self.test_set = ImageFolderLMDB(db_path=self.data_dir_domain + "_test",
-                                            transform=self._default_test_transforms())
+                                            transform=self.get_test_transform())
 
     def train_dataloader(self) -> TRAIN_DATALOADERS:
         return DataLoader(dataset=self.train_set,
