@@ -1,10 +1,10 @@
 """META LEARNING BASE - based on torchmeta from https://arxiv.org/abs/1909.06576 """
 from pytorch_lightning.utilities.types import TRAIN_DATALOADERS, EVAL_DATALOADERS
-#from torchmeta.transforms import ClassSplitter
+#from lightningdata.thirdparty.torchmeta.transforms import ClassSplitter
 
 from lightningdata.modules.datamodule_base import LightningDataBase
 from typing import Any, Optional
-from torchmeta.utils.data.dataloader import BatchMetaDataLoader
+from lightningdata.thirdparty.torchmeta.utils.data.dataloader import BatchMetaDataLoader
 
 
 class MetaLearningDataModule(LightningDataBase):
